/* Enunciado 01
	Se tienen dos objetos arrays de Items, class ArrItems
	Ambos contiene las ventas de un comercio, en dos das sucesivos de una semana
	cualquiera.
	El objeto vtasVier contiene las ventas del viernes.
	El objeto vtasSab contiene las ventas del sbado.
	Se pide:
		1) - Generar un objeto lista de lo vendido el sbado que no se vendi el
		viernes. Estamos queriendo detectar que es lo que se vende exclusivamente
		el fin de semana. Llamamos a este objeto vtasFSem. Queremos que en este
		objeto lista las ventas se acumulen por cdigo.
		2) - Generar un objeto lista de lo vendido el sbado que tambien se vendi
		el viernes. Estamos queriendo detectar que es lo que se vende habitual
		mente, lo que la gente consume siempre. Llamamos a este objeto vtasEver.
		A diferencia del punto anterior, queremos que cada item del objeto vtasSab
		se incluya  en vtasEver directamente, sin acumulacin.  					*/

/* Estrategia de resolucin.
	En principio, tenemos gran parte de comportamiento listo.
	En la parte de array de items, podemos usar virtual int existe(int);
	(Existe la clave parmetro ?, class BusqSec.)
	En la parte de listas, en class lista, tambien tenemos
	void inclOrd(int, float, int), (Inserta nodos. Lista ordenada por cdigo. Se
	preocupa por la unicidad del codigo del item.)

	Evidentemente, es un problema que se resuelve con el concurso de varias
	clases. Para ordenar un poco esto, definimos que todo lo que haremos est
	dentro de una clase, naturalmente class Enunc01. Esta clase tendr por lo
	menos dos mtodos, que implementarn lo que pide en enunciado, que llamaremos
	punto01 y punto02.

	Y como relacionamos estas clases?  Comencemos por la salida, las listas.
	Nuestra class Enunc01 debe
		. heredar (Relacin "es un"), de class Lista ?.
		. debe tener (Relacin "tiene un") class Lista ?.
		. simplemente usar objetos lista ?

	Es evidente que class Enunc01 no es una especializacin de Lista, entonces
	podramos optar por cualquiera de las otras dos alternativas. Si suponemos
	que los objetos Lista que generamos en punto01 y punto02 sern usados por
	otros futuros mtodos de esta clase o herederas, necesitamos de la relacin
	"tiene un"

	La entrada de nuestro programa son los arrays de items. Una vez procesados,
	la informacin como la queremos est en las listas, no los necesitamos mas,
	entonces deberamos deshacernos de ellos. Un buen lugar de definirlos es en
	punto01 y punto02. O sea que usaremos objetos arrays de 	items, de la
	clase derivada BusqSeq, porque precisaremos de este mtodo

	Al trabajo.

	Nota: En la programacin de este enunciado, se descubre que el atributo talle
	definido como protected en ArrItems, conteniendo la informacin del tamao
	del array de items no esta disponible para la clase enunc01. Que hacemos ?
	Declaramos una clase Ventas que hereda publicamente de BusqSeq, que subsana
	este y algn otro inconveniente, y adelante ...									*/

# include <C:\AED2004\Unidad3\Items\Items.cpp>
# include <C:\AED2004\Unidad4\ventas\Ventas.cpp>
# include <C:\AED2004\Unidad4\Lista\Lista.cpp>
class Enunc01{
	protected:
		Lista vtasFSem, vtasEver;
			/* Enunc01 tiene un objeto Lista, llamado ptrVen. Es un puntero a Nodo.
				Como un puntero a Nodo ? Porque Lista hereda de ListEnl,
				donde se lo define 	Nodo * frente; 									*/
		void punto01();
		void punto02();
	public:
		void implementar();
	};

	void Enunc01::punto01(){
		int codVSab;            // Codigo de un item vendido el sbado ...
		float valVSab;          // Y su valor
		int vendVie;				// Vendido el viernes
		Nodo *ptrNodo;          // Lo necesita existe() de Lista
		int exist;					// Lo inicializa existe de lista al retornar
		Ventas vtasVie(10,'R'); // Generamos un array de 10 objetos item random
		Ventas vtasSab(30,'R'); // Generamos un array de 30 objetos item random
		int venSab = vtasSab.getTalle(); // cantidad de ventas del sbado
		Item  item;
		for(int i=0;i<venSab;++i){ // Recorremos esas ventas de sbado
			item = vtasSab.ptrItem[i].getItem(); // Obtenemos un item
			codVSab = item.getCodigo();	 // ahora su cdigo
			valVSab = item.getValor();
			vendVie = vtasVie.existe(codVSab); // Veamos las ventas del viernes
			if (!vendVie){	// Si no fue vendido el viernes nos interesa ...
				exist = vtasFSem.existe(codVSab,ptrNodo);
				if (exist)                	// Este cdigo ya estaba en la cinta.
					vtasFSem.actValor(codVSab,valVSab);  //lo actualizamos
				else                       // No estaba,
					vtasFSem.inclOrd(codVSab,valVSab);  // lo incluimos
			}
		} // for
		cout << "Enunciado 001, pto 1 \n";
		cout << "Ventas fin de semana \n";
		vtasFSem.toString();
	}

		void Enunc01::punto02(){
		int codVSab;            // Codigo de un item vendido el sbado ...
		float valVSab;          // Y su valor
		int vendVie;				// Vendido el viernes
		Ventas vtasVie(30,'R'); // Generamos un array de 10 objetos item random
		Ventas vtasSab(30,'R'); // Generamos un array de 30 objetos item random
		int venSab = vtasSab.getTalle(); // cantidad de ventas del sbado
		Item  item;
		for(int i=0;i<venSab;++i){ // Recorremos esas ventas de sbado
			item = vtasSab.ptrItem[i].getItem(); // Obtenemos un item
			codVSab = item.getCodigo();	 // ahora su cdigo,
			valVSab = item.getValor();     // su valor
			vendVie = vtasVie.existe(codVSab); // Veamos las ventas del viernes
			if (vendVie) 	// Si fue vendido el viernes nos interesa ...
					vtasEver.incluir(codVSab,valVSab);  // lo incluimos
		} // for
		cout << "Enunciado 001, pto 2 \n";
		cout << "Ventas no estacional \n";
		vtasEver.toString();
	}



	void Enunc01::implementar(){
		// punto01();
		punto02();
	}


